@@ -1,38 +1,40 @@
 import numpy as np
 from skimage import io
 
-
 # Import / export / convert_type methods.
 
 
-def import_image(path, preprocessor=None):
+def import_image(path, preprocessors=None, *args, **kwargs):
     """
     :param path: Directory of the image
-    :param preprocessor: An arbitrary class having a function 'process' which is performed on the images on import
+    :param preprocessors: list of classes with a process method.
     :return: a numpy array containing the image
     """
     img = io.imread(path)
 
-    print("Image imported from:", path)
-    if preprocessor is not None:
-        if hasattr(preprocessor, '__iter__'):
-            for pp in preprocessor:
-                img = pp.process(img=img)
+    if kwargs.get('Verbose', True):
+        print("Image imported from:", path)
+
+    if preprocessors is not None:
+        if hasattr(preprocessors, '__iter__'):
+            for pp in preprocessors:
+                img = pp.process(img=img, *args, **kwargs)
+
         else:
-            img = preprocessor.process(img=img)
+            img = preprocessors.process(img=img, *args, **kwargs)
 
     return img
 
 
-def import_image_seq(paths, preprocessor=None):
+def import_image_seq(paths, preprocessor=None, *args, **kwargs):
     """
     :param paths: Directories of the images
-    :param preprocessor: An arbitrary class having a function 'process' which is performed on the images on import
+    :param preprocessor: An arbitrary class having a function 'solvers' which is performed on the images on import
     :return: A list of images as numpy arrays
     """
     imgs = []
     for path in paths:
-        img = import_image(path, preprocessor)
+        img = import_image(path, preprocessor, *args, **kwargs)
         imgs.append(img)
     return imgs
 
